class Admin::WritingsController < OrbitMemberController
  include Admin::PersonalWritingsHelper
  layout "member_plugin"

  before_action :set_writing, only: [:show, :edit , :update, :destroy]
  before_action :set_plugin
  before_action :get_settings,:only => [:new, :edit, :setting]

  before_action :need_access_right
  before_action :allow_admin_only, :only => [:index, :setting]

  def index
    @filter = params[:filter]
    @mq = params[:mq]
    @new_filter = params[:new_filter]
    @filter = {} if @filter.nil?
    @filter['category'] = [] if @filter['category'].nil?
    if @new_filter.present?
      if @filter['category'].include? @new_filter[:id]
        @filter['category'].delete(@new_filter[:id])
      else
        @filter['category'] << @new_filter[:id]
      end
    end
    if params[:clear] != 'true'
      if(params[:new_filter] != nil && params[:new_filter][:type] == 'category')
        @writings = Writing.where(:category_id.in=> @filter['category']).order_by(:year=>'desc',:month=>'desc',:id=>'desc').page(params[:page]).per(10)
      else
        @writings = Writing.order_by(:year=>'desc',:month=>'desc',:id=>'desc').page(params[:page]).per(10)
      end
    else
      redirect_to admin_writings_url
    end
  end

  def new
    @member = MemberProfile.find_by(:uid=>params['uid']) rescue nil
    @writing = Writing.new
    if params[:desktop]
      render :layout => false
    end
  end
  def analysis_report
    role = params[:role_id]
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    graph_by = params[:graph_by]

    @data = get_chart_data(year_start,year_end,role,params[:graph_by])

    render :layout => false
  end

  def download_excel
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    @data = get_data_for_excel(year_start,year_end)
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="writings.xlsx"'
      }
    end
  end
  def create

    if !writing_params['member_profile_id'].blank?

      @member = MemberProfile.find(writing_params['member_profile_id']) rescue nil
      @writing = Writing.new(writing_params)
      @writing.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      else
        redirect_to params['referer_url']
      end

    elsif !params[:author_members].blank?

      params[:author_members].each do |author_member|

        writing_params['member_profile_id'] = author_member
        @writing = Writing.new(writing_params)
        @writing.save

        if params[:desktop] == "true"
          render json: {"data" => get_paper_list}.to_json
        end

      end

      redirect_to params['referer_url']

    else

      writing_params['member_profile_id'] = User.find(current_user.id).member_profile_id

      @writing = Writing.new(writing_params)
      @writing.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      end

      redirect_to params['referer_url']

    end
    
  end

  def edit
    @member = @writing.member_profile rescue nil
    if params[:desktop]
      render :layout => false
    end
  end

  def update
    @member = @writing.member_profile rescue nil
    @writing.update_attributes(writing_params)
    @writing.save
    if params[:desktop] == "true"
      render json: {"data" => get_paper_list}.to_json
    else
      redirect_to params['referer_url']
    end
  end

  def destroy
    @writing.destroy
    respond_to do |format|
      format.html { redirect_to(admin_writings_url) }
      # format.xml { head :ok }
      format.js
      format.json {render json: {"success" => true}}
      end
  end

  def excel_format
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="writings_format.xlsx"'
      }
    end
  end

  def import_from_excel
    workbook = RubyXL::Parser.parse(params["import_file"].tempfile)
    sheet = workbook[0]
    if sheet.count <= 503
      sheet.each_with_index do |row, i|
        next if i < 3
        user = User.where(:user_name => row.cells[0].value).first rescue nil
        if !user.nil?
          mp = user.member_profile
          import_this_writing(row,mp)
        end
      end
      redirect_to admin_writings_url
    else
      redirect_to admin_writings_url(:error => "1")
    end
  end


  def toggle_hide
    if params[:ids]
      @writings = Writing.any_in(_id: params[:ids])

      @writings.each do |writing|
        writing.is_hidden = params[:disable]
        writing.save
      end
    end

    render json: {"success"=>true}
  end

  def setting
  end

  def frontend_setting
    @member = MemberProfile.find_by(:uid=>params['uid']) rescue nil
    @intro = WritingIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? WritingIntro.new({:member_profile_id=>@member.id}) : @intro
  end

  def update_frontend_setting
    @member = MemberProfile.find(intro_params['member_profile_id']) rescue nil
    @intro = WritingIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? WritingIntro.new({:member_profile_id=>@member.id}) : @intro
    @intro.update_attributes(intro_params)
    @intro.save
    redirect_to URI.encode('/admin/members/'+@member.to_param+'/writing')
  end

  def get_settings
  end

  def set_plugin
    @plugin = OrbitApp::Plugin::Registration.all.select{|plugin| plugin.app_name.eql? 'Writing'}.first
    @module_app = ModuleApp.where(:key=>'personal_writing').first
    @module_app = ModuleApp.create(:key=>'personal_writing',:title=>'PersonalWriting','frontend_enable'=>true) if @module_app.nil?
    @categories = @module_app.categories
  end

  private

  def set_writing
    path = request.path.split('/')
    if path.last.include? '-'
      uid = path[-1].split("-").last
      uid = uid.split("?").first
    else
      uid = path[-2].split("-").last
      uid = uid.split("?").first
    end
     @writing = Writing.find_by(:uid => uid) rescue Writing.find(params[:id])
  end

  def writing_params
    params.require(:writing).permit! rescue nil
  end

  def intro_params
    params.require(:writing_intro).permit! rescue nil
  end
end